# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _medsubdomain
else:
    import _medsubdomain

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator_medsubdomain_module(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medsubdomain.delete_SwigPyIterator_medsubdomain_module

    def value(self):
        return _medsubdomain.SwigPyIterator_medsubdomain_module_value(self)

    def incr(self, n=1):
        return _medsubdomain.SwigPyIterator_medsubdomain_module_incr(self, n)

    def decr(self, n=1):
        return _medsubdomain.SwigPyIterator_medsubdomain_module_decr(self, n)

    def distance(self, x):
        return _medsubdomain.SwigPyIterator_medsubdomain_module_distance(self, x)

    def equal(self, x):
        return _medsubdomain.SwigPyIterator_medsubdomain_module_equal(self, x)

    def copy(self):
        return _medsubdomain.SwigPyIterator_medsubdomain_module_copy(self)

    def next(self):
        return _medsubdomain.SwigPyIterator_medsubdomain_module_next(self)

    def __next__(self):
        return _medsubdomain.SwigPyIterator_medsubdomain_module___next__(self)

    def previous(self):
        return _medsubdomain.SwigPyIterator_medsubdomain_module_previous(self)

    def advance(self, n):
        return _medsubdomain.SwigPyIterator_medsubdomain_module_advance(self, n)

    def __eq__(self, x):
        return _medsubdomain.SwigPyIterator_medsubdomain_module___eq__(self, x)

    def __ne__(self, x):
        return _medsubdomain.SwigPyIterator_medsubdomain_module___ne__(self, x)

    def __iadd__(self, n):
        return _medsubdomain.SwigPyIterator_medsubdomain_module___iadd__(self, n)

    def __isub__(self, n):
        return _medsubdomain.SwigPyIterator_medsubdomain_module___isub__(self, n)

    def __add__(self, n):
        return _medsubdomain.SwigPyIterator_medsubdomain_module___add__(self, n)

    def __sub__(self, *args):
        return _medsubdomain.SwigPyIterator_medsubdomain_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self

# Register SwigPyIterator_medsubdomain_module in _medsubdomain:
_medsubdomain.SwigPyIterator_medsubdomain_module_swigregister(SwigPyIterator_medsubdomain_module)
HAVE_CC_C99 = _medsubdomain.HAVE_CC_C99
HAVE_CUSERID = _medsubdomain.HAVE_CUSERID
HAVE_DLFCN_H = _medsubdomain.HAVE_DLFCN_H
HAVE_FTIME = _medsubdomain.HAVE_FTIME
HAVE_GETEUID = _medsubdomain.HAVE_GETEUID
HAVE_GETPWUID = _medsubdomain.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medsubdomain.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medsubdomain.HAVE_H5PUBLIC_H
HAVE_INT64 = _medsubdomain.HAVE_INT64
HAVE_INTTYPES_H = _medsubdomain.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medsubdomain.HAVE_MALLOC_H
HAVE_PWD_H = _medsubdomain.HAVE_PWD_H
HAVE_STDBOOL_H = _medsubdomain.HAVE_STDBOOL_H
HAVE_STDINT_H = _medsubdomain.HAVE_STDINT_H
HAVE_STDIO_H = _medsubdomain.HAVE_STDIO_H
HAVE_STDLIB_H = _medsubdomain.HAVE_STDLIB_H
HAVE_STRINGS_H = _medsubdomain.HAVE_STRINGS_H
HAVE_STRING_H = _medsubdomain.HAVE_STRING_H
HAVE_SYS_STAT_H = _medsubdomain.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medsubdomain.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medsubdomain.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medsubdomain.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medsubdomain.HAVE_UNISTD_H
HAVE__BOOL = _medsubdomain.HAVE__BOOL
MED_CHECK_23FORMAT = _medsubdomain.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medsubdomain.MED_HAVE_FORTRAN
MESGERR = _medsubdomain.MESGERR
PACKAGE = _medsubdomain.PACKAGE
PACKAGE_BUGREPORT = _medsubdomain.PACKAGE_BUGREPORT
PACKAGE_NAME = _medsubdomain.PACKAGE_NAME
PACKAGE_STRING = _medsubdomain.PACKAGE_STRING
PACKAGE_URL = _medsubdomain.PACKAGE_URL
PACKAGE_VERSION = _medsubdomain.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medsubdomain.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medsubdomain.SIZEOF_INT
SIZEOF_LONG = _medsubdomain.SIZEOF_LONG
STDC_HEADERS = _medsubdomain.STDC_HEADERS
VERSION = _medsubdomain.VERSION
HDF_VERSION_REF = _medsubdomain.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medsubdomain.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medsubdomain.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medsubdomain.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medsubdomain.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medsubdomain.H5F_LIBVER_18
MED_MAJOR_NUM = _medsubdomain.MED_MAJOR_NUM
MED_MINOR_NUM = _medsubdomain.MED_MINOR_NUM
MED_RELEASE_NUM = _medsubdomain.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medsubdomain.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medsubdomain.MED_4_LATEST_MINOR
MED_5_LATEST_MINOR = _medsubdomain.MED_5_LATEST_MINOR
MED_50_LATEST_RELEASE = _medsubdomain.MED_50_LATEST_RELEASE
MED_NUM_MAJEUR = _medsubdomain.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medsubdomain.MED_NUM_MINEUR
MED_NUM_RELEASE = _medsubdomain.MED_NUM_RELEASE
MED_VERSION_STR = _medsubdomain.MED_VERSION_STR
MED_MAX_PARA = _medsubdomain.MED_MAX_PARA
MED_COMMENT_SIZE = _medsubdomain.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medsubdomain.MED_IDENT_SIZE
MED_NAME_SIZE = _medsubdomain.MED_NAME_SIZE
MED_SNAME_SIZE = _medsubdomain.MED_SNAME_SIZE
MED_LNAME_SIZE = _medsubdomain.MED_LNAME_SIZE
MED_SNAME_BLANK = _medsubdomain.MED_SNAME_BLANK
MED_NAME_BLANK = _medsubdomain.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medsubdomain.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medsubdomain.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medsubdomain.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medsubdomain.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medsubdomain.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medsubdomain.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medsubdomain.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medsubdomain.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medsubdomain.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medsubdomain.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medsubdomain.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medsubdomain.MED_ACC_RDONLY
MED_ACC_RDWR = _medsubdomain.MED_ACC_RDWR
MED_ACC_RDEXT = _medsubdomain.MED_ACC_RDEXT
MED_ACC_CREAT = _medsubdomain.MED_ACC_CREAT
MED_ACC_UNDEF = _medsubdomain.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medsubdomain.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medsubdomain.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medsubdomain.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medsubdomain.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medsubdomain.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medsubdomain.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medsubdomain.MED_UNDEF_GRID_TYPE
MED_CELL = _medsubdomain.MED_CELL
MED_DESCENDING_FACE = _medsubdomain.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medsubdomain.MED_DESCENDING_EDGE
MED_NODE = _medsubdomain.MED_NODE
MED_NODE_ELEMENT = _medsubdomain.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medsubdomain.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medsubdomain.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medsubdomain.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medsubdomain.MED_N_ENTITY_TYPES
MED_COORDINATE = _medsubdomain.MED_COORDINATE
MED_CONNECTIVITY = _medsubdomain.MED_CONNECTIVITY
MED_NAME = _medsubdomain.MED_NAME
MED_NUMBER = _medsubdomain.MED_NUMBER
MED_FAMILY_NUMBER = _medsubdomain.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medsubdomain.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medsubdomain.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medsubdomain.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medsubdomain.MED_INDEX_FACE
MED_INDEX_NODE = _medsubdomain.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medsubdomain.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medsubdomain.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medsubdomain.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medsubdomain.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medsubdomain.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medsubdomain.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medsubdomain.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medsubdomain.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medsubdomain.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medsubdomain.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medsubdomain.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medsubdomain.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medsubdomain.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medsubdomain.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medsubdomain.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medsubdomain.MED_INTERNAL_UNDEF
MED_DOUBLE = _medsubdomain.MED_DOUBLE
MED_FLOAT64 = _medsubdomain.MED_FLOAT64
MED_FLOAT32 = _medsubdomain.MED_FLOAT32
MED_INT32 = _medsubdomain.MED_INT32
MED_INT64 = _medsubdomain.MED_INT64
MED_INT = _medsubdomain.MED_INT
MED_ATT_FLOAT64 = _medsubdomain.MED_ATT_FLOAT64
MED_ATT_INT = _medsubdomain.MED_ATT_INT
MED_ATT_NAME = _medsubdomain.MED_ATT_NAME
MED_ATT_UNDEF = _medsubdomain.MED_ATT_UNDEF
MED_MESH = _medsubdomain.MED_MESH
MED_FIELD = _medsubdomain.MED_FIELD
MED_LIBRARY = _medsubdomain.MED_LIBRARY
MED_FILE = _medsubdomain.MED_FILE
MED_MESH_SUPPORT = _medsubdomain.MED_MESH_SUPPORT
MED_ELSTRUCT = _medsubdomain.MED_ELSTRUCT
MED_FAMILY = _medsubdomain.MED_FAMILY
MED_EQUIVALENCE = _medsubdomain.MED_EQUIVALENCE
MED_GROUP = _medsubdomain.MED_GROUP
MED_JOINT = _medsubdomain.MED_JOINT
MED_LOCALIZATION = _medsubdomain.MED_LOCALIZATION
MED_PROFILE = _medsubdomain.MED_PROFILE
MED_FILTER = _medsubdomain.MED_FILTER
MED_INTERPOLATION = _medsubdomain.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medsubdomain.MED_NUMERICAL_DATA
MED_LINK = _medsubdomain.MED_LINK
MED_CLASS_UNDEF = _medsubdomain.MED_CLASS_UNDEF
MED_CLASS_ALL = _medsubdomain.MED_CLASS_ALL
MED_POINT1 = _medsubdomain.MED_POINT1
MED_SEG2 = _medsubdomain.MED_SEG2
MED_SEG3 = _medsubdomain.MED_SEG3
MED_SEG4 = _medsubdomain.MED_SEG4
MED_TRIA3 = _medsubdomain.MED_TRIA3
MED_QUAD4 = _medsubdomain.MED_QUAD4
MED_TRIA6 = _medsubdomain.MED_TRIA6
MED_TRIA7 = _medsubdomain.MED_TRIA7
MED_QUAD8 = _medsubdomain.MED_QUAD8
MED_QUAD9 = _medsubdomain.MED_QUAD9
MED_TETRA4 = _medsubdomain.MED_TETRA4
MED_PYRA5 = _medsubdomain.MED_PYRA5
MED_PENTA6 = _medsubdomain.MED_PENTA6
MED_HEXA8 = _medsubdomain.MED_HEXA8
MED_TETRA10 = _medsubdomain.MED_TETRA10
MED_OCTA12 = _medsubdomain.MED_OCTA12
MED_PYRA13 = _medsubdomain.MED_PYRA13
MED_PENTA15 = _medsubdomain.MED_PENTA15
MED_PENTA18 = _medsubdomain.MED_PENTA18
MED_HEXA20 = _medsubdomain.MED_HEXA20
MED_HEXA27 = _medsubdomain.MED_HEXA27
MED_POLYGON = _medsubdomain.MED_POLYGON
MED_POLYGON2 = _medsubdomain.MED_POLYGON2
MED_POLYHEDRON = _medsubdomain.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medsubdomain.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medsubdomain.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medsubdomain.MED_NONE
MED_NO_GEOTYPE = _medsubdomain.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medsubdomain.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medsubdomain.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medsubdomain.MED_ALL_GEOTYPE
MED_GEO_ALL = _medsubdomain.MED_GEO_ALL
MED_N_CELL_GEO = _medsubdomain.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medsubdomain.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medsubdomain.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medsubdomain.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medsubdomain.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medsubdomain.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medsubdomain.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medsubdomain.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medsubdomain.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medsubdomain.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medsubdomain.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medsubdomain.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medsubdomain.MED_NODAL
MED_DESCENDING = _medsubdomain.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medsubdomain.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medsubdomain.MED_NO_CMODE
MED_CARTESIAN = _medsubdomain.MED_CARTESIAN
MED_CYLINDRICAL = _medsubdomain.MED_CYLINDRICAL
MED_SPHERICAL = _medsubdomain.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medsubdomain.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medsubdomain.MED_FALSE
MED_TRUE = _medsubdomain.MED_TRUE
MED_GAUSS_ELNO = _medsubdomain.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medsubdomain.MED_IPOINT_ELNO
MED_NO_NAME = _medsubdomain.MED_NO_NAME
MED_NO_MESHNAME = _medsubdomain.MED_NO_MESHNAME
MED_NO_MESH = _medsubdomain.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medsubdomain.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medsubdomain.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medsubdomain.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medsubdomain.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medsubdomain.MED_NO_PROFILE
MED_NO_GROUP = _medsubdomain.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medsubdomain.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medsubdomain.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medsubdomain.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medsubdomain.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medsubdomain.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medsubdomain.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medsubdomain.MED_SORT_DTIT
MED_SORT_ITDT = _medsubdomain.MED_SORT_ITDT
MED_SORT_UNDEF = _medsubdomain.MED_SORT_UNDEF
MED_ALL_DT = _medsubdomain.MED_ALL_DT
MED_ALL_IT = _medsubdomain.MED_ALL_IT
MED_NO_DT = _medsubdomain.MED_NO_DT
MED_NO_IT = _medsubdomain.MED_NO_IT
MED_UNDEF_DT = _medsubdomain.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medsubdomain.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medsubdomain.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medsubdomain.med_filter_nspaces_get, _medsubdomain.med_filter_nspaces_set)
    memspace = property(_medsubdomain.med_filter_memspace_get, _medsubdomain.med_filter_memspace_set)
    diskspace = property(_medsubdomain.med_filter_diskspace_get, _medsubdomain.med_filter_diskspace_set)
    nentity = property(_medsubdomain.med_filter_nentity_get, _medsubdomain.med_filter_nentity_set)
    nvaluesperentity = property(_medsubdomain.med_filter_nvaluesperentity_get, _medsubdomain.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medsubdomain.med_filter_nconstituentpervalue_get, _medsubdomain.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medsubdomain.med_filter_constituentselect_get, _medsubdomain.med_filter_constituentselect_set)
    switchmode = property(_medsubdomain.med_filter_switchmode_get, _medsubdomain.med_filter_switchmode_set)
    filterarraysize = property(_medsubdomain.med_filter_filterarraysize_get, _medsubdomain.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medsubdomain.med_filter_filterarray23v30_get, _medsubdomain.med_filter_filterarray23v30_set)
    profilearraysize = property(_medsubdomain.med_filter_profilearraysize_get, _medsubdomain.med_filter_profilearraysize_set)
    storagemode = property(_medsubdomain.med_filter_storagemode_get, _medsubdomain.med_filter_storagemode_set)
    profilename = property(_medsubdomain.med_filter_profilename_get, _medsubdomain.med_filter_profilename_set)

    def __init__(self):
        r"""__init__(self) -> med_filter"""
        _medsubdomain.med_filter_swiginit(self, _medsubdomain.new_med_filter())
    __swig_destroy__ = _medsubdomain.delete_med_filter

# Register med_filter in _medsubdomain:
_medsubdomain.med_filter_swigregister(med_filter)
MED_NO_FILTER_SIZE = _medsubdomain.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medsubdomain.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medsubdomain.med_file_version_majeur_get, _medsubdomain.med_file_version_majeur_set)
    mineur = property(_medsubdomain.med_file_version_mineur_get, _medsubdomain.med_file_version_mineur_set)
    release = property(_medsubdomain.med_file_version_release_get, _medsubdomain.med_file_version_release_set)

    def __init__(self):
        r"""__init__(self) -> med_file_version"""
        _medsubdomain.med_file_version_swiginit(self, _medsubdomain.new_med_file_version())
    __swig_destroy__ = _medsubdomain.delete_med_file_version

# Register med_file_version in _medsubdomain:
_medsubdomain.med_file_version_swigregister(med_file_version)
class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medsubdomain.med_memfile_app_image_ptr_get, _medsubdomain.med_memfile_app_image_ptr_set)
    app_image_size = property(_medsubdomain.med_memfile_app_image_size_get, _medsubdomain.med_memfile_app_image_size_set)
    ref_count = property(_medsubdomain.med_memfile_ref_count_get, _medsubdomain.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medsubdomain.med_memfile_fapl_image_ptr_get, _medsubdomain.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medsubdomain.med_memfile_fapl_image_size_get, _medsubdomain.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medsubdomain.med_memfile_fapl_ref_count_get, _medsubdomain.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medsubdomain.med_memfile_vfd_image_ptr_get, _medsubdomain.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medsubdomain.med_memfile_vfd_image_size_get, _medsubdomain.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medsubdomain.med_memfile_vfd_ref_count_get, _medsubdomain.med_memfile_vfd_ref_count_set)
    flags = property(_medsubdomain.med_memfile_flags_get, _medsubdomain.med_memfile_flags_set)

    def __init__(self):
        r"""__init__(self) -> med_memfile"""
        _medsubdomain.med_memfile_swiginit(self, _medsubdomain.new_med_memfile())
    __swig_destroy__ = _medsubdomain.delete_med_memfile

# Register med_memfile in _medsubdomain:
_medsubdomain.med_memfile_swigregister(med_memfile)

def MEDgetEntityTypeIt(entitytype):
    return _medsubdomain.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medsubdomain.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medsubdomain.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medsubdomain.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medsubdomain.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medsubdomain.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medsubdomain.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medsubdomain.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medsubdomain.MED_PARTICLE_NAME
MED_BALL_NAME = _medsubdomain.MED_BALL_NAME
MED_BEAM_NAME = _medsubdomain.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medsubdomain.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medsubdomain.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medsubdomain.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medsubdomain.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medsubdomain.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medsubdomain.MEDBOOL___bool__(self)

    def __len__(self):
        return _medsubdomain.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medsubdomain.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medsubdomain.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medsubdomain.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medsubdomain.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medsubdomain.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medsubdomain.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medsubdomain.MEDBOOL_pop(self)

    def append(self, x):
        return _medsubdomain.MEDBOOL_append(self, x)

    def empty(self):
        return _medsubdomain.MEDBOOL_empty(self)

    def size(self):
        return _medsubdomain.MEDBOOL_size(self)

    def swap(self, v):
        return _medsubdomain.MEDBOOL_swap(self, v)

    def begin(self):
        return _medsubdomain.MEDBOOL_begin(self)

    def end(self):
        return _medsubdomain.MEDBOOL_end(self)

    def rbegin(self):
        return _medsubdomain.MEDBOOL_rbegin(self)

    def rend(self):
        return _medsubdomain.MEDBOOL_rend(self)

    def clear(self):
        return _medsubdomain.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medsubdomain.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medsubdomain.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medsubdomain.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        _medsubdomain.MEDBOOL_swiginit(self, _medsubdomain.new_MEDBOOL(*args))

    def push_back(self, x):
        return _medsubdomain.MEDBOOL_push_back(self, x)

    def front(self):
        return _medsubdomain.MEDBOOL_front(self)

    def back(self):
        return _medsubdomain.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medsubdomain.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medsubdomain.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medsubdomain.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medsubdomain.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medsubdomain.MEDBOOL_capacity(self)
    __swig_destroy__ = _medsubdomain.delete_MEDBOOL

# Register MEDBOOL in _medsubdomain:
_medsubdomain.MEDBOOL_swigregister(MEDBOOL)
cvar = _medsubdomain.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medsubdomain.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medsubdomain.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medsubdomain.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medsubdomain.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medsubdomain.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medsubdomain.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medsubdomain.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medsubdomain.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medsubdomain.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medsubdomain.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medsubdomain.MEDFLOAT_pop(self)

    def append(self, x):
        return _medsubdomain.MEDFLOAT_append(self, x)

    def empty(self):
        return _medsubdomain.MEDFLOAT_empty(self)

    def size(self):
        return _medsubdomain.MEDFLOAT_size(self)

    def swap(self, v):
        return _medsubdomain.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medsubdomain.MEDFLOAT_begin(self)

    def end(self):
        return _medsubdomain.MEDFLOAT_end(self)

    def rbegin(self):
        return _medsubdomain.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medsubdomain.MEDFLOAT_rend(self)

    def clear(self):
        return _medsubdomain.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medsubdomain.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medsubdomain.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medsubdomain.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        _medsubdomain.MEDFLOAT_swiginit(self, _medsubdomain.new_MEDFLOAT(*args))

    def push_back(self, x):
        return _medsubdomain.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medsubdomain.MEDFLOAT_front(self)

    def back(self):
        return _medsubdomain.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medsubdomain.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medsubdomain.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medsubdomain.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medsubdomain.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medsubdomain.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medsubdomain.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medsubdomain.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medsubdomain.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medsubdomain.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medsubdomain.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medsubdomain.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medsubdomain.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medsubdomain.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medsubdomain.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medsubdomain.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medsubdomain.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medsubdomain.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medsubdomain.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medsubdomain.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medsubdomain.delete_MEDFLOAT

# Register MEDFLOAT in _medsubdomain:
_medsubdomain.MEDFLOAT_swigregister(MEDFLOAT)

MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medsubdomain.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medsubdomain.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medsubdomain.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medsubdomain.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medsubdomain.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medsubdomain.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medsubdomain.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medsubdomain.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medsubdomain.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medsubdomain.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medsubdomain.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medsubdomain.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medsubdomain.MEDFLOAT32_empty(self)

    def size(self):
        return _medsubdomain.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medsubdomain.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medsubdomain.MEDFLOAT32_begin(self)

    def end(self):
        return _medsubdomain.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medsubdomain.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medsubdomain.MEDFLOAT32_rend(self)

    def clear(self):
        return _medsubdomain.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medsubdomain.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medsubdomain.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medsubdomain.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        _medsubdomain.MEDFLOAT32_swiginit(self, _medsubdomain.new_MEDFLOAT32(*args))

    def push_back(self, x):
        return _medsubdomain.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medsubdomain.MEDFLOAT32_front(self)

    def back(self):
        return _medsubdomain.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medsubdomain.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medsubdomain.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medsubdomain.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medsubdomain.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medsubdomain.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medsubdomain.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medsubdomain.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medsubdomain.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medsubdomain.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medsubdomain.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medsubdomain.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medsubdomain.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medsubdomain.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medsubdomain.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medsubdomain.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medsubdomain.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medsubdomain.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medsubdomain.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medsubdomain.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medsubdomain.delete_MEDFLOAT32

# Register MEDFLOAT32 in _medsubdomain:
_medsubdomain.MEDFLOAT32_swigregister(MEDFLOAT32)

MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medsubdomain.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medsubdomain.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medsubdomain.MEDINT___bool__(self)

    def __len__(self):
        return _medsubdomain.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medsubdomain.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medsubdomain.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medsubdomain.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medsubdomain.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medsubdomain.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medsubdomain.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medsubdomain.MEDINT_pop(self)

    def append(self, x):
        return _medsubdomain.MEDINT_append(self, x)

    def empty(self):
        return _medsubdomain.MEDINT_empty(self)

    def size(self):
        return _medsubdomain.MEDINT_size(self)

    def swap(self, v):
        return _medsubdomain.MEDINT_swap(self, v)

    def begin(self):
        return _medsubdomain.MEDINT_begin(self)

    def end(self):
        return _medsubdomain.MEDINT_end(self)

    def rbegin(self):
        return _medsubdomain.MEDINT_rbegin(self)

    def rend(self):
        return _medsubdomain.MEDINT_rend(self)

    def clear(self):
        return _medsubdomain.MEDINT_clear(self)

    def get_allocator(self):
        return _medsubdomain.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medsubdomain.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medsubdomain.MEDINT_erase(self, *args)

    def __init__(self, *args):
        _medsubdomain.MEDINT_swiginit(self, _medsubdomain.new_MEDINT(*args))

    def push_back(self, x):
        return _medsubdomain.MEDINT_push_back(self, x)

    def front(self):
        return _medsubdomain.MEDINT_front(self)

    def back(self):
        return _medsubdomain.MEDINT_back(self)

    def assign(self, n, x):
        return _medsubdomain.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medsubdomain.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medsubdomain.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medsubdomain.MEDINT_reserve(self, n)

    def capacity(self):
        return _medsubdomain.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medsubdomain.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medsubdomain.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medsubdomain.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medsubdomain.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medsubdomain.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medsubdomain.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medsubdomain.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medsubdomain.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medsubdomain.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medsubdomain.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medsubdomain.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medsubdomain.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medsubdomain.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medsubdomain.MEDINT___ne__(self, value)
    __swig_destroy__ = _medsubdomain.delete_MEDINT

# Register MEDINT in _medsubdomain:
_medsubdomain.MEDINT_swigregister(MEDINT)

MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medsubdomain.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medsubdomain.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medsubdomain.MEDCHAR___bool__(self)

    def __len__(self):
        return _medsubdomain.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medsubdomain.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medsubdomain.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medsubdomain.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medsubdomain.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medsubdomain.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medsubdomain.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medsubdomain.MEDCHAR_pop(self)

    def append(self, x):
        return _medsubdomain.MEDCHAR_append(self, x)

    def empty(self):
        return _medsubdomain.MEDCHAR_empty(self)

    def size(self):
        return _medsubdomain.MEDCHAR_size(self)

    def swap(self, v):
        return _medsubdomain.MEDCHAR_swap(self, v)

    def begin(self):
        return _medsubdomain.MEDCHAR_begin(self)

    def end(self):
        return _medsubdomain.MEDCHAR_end(self)

    def rbegin(self):
        return _medsubdomain.MEDCHAR_rbegin(self)

    def rend(self):
        return _medsubdomain.MEDCHAR_rend(self)

    def clear(self):
        return _medsubdomain.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medsubdomain.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medsubdomain.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medsubdomain.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        _medsubdomain.MEDCHAR_swiginit(self, _medsubdomain.new_MEDCHAR(*args))

    def push_back(self, x):
        return _medsubdomain.MEDCHAR_push_back(self, x)

    def front(self):
        return _medsubdomain.MEDCHAR_front(self)

    def back(self):
        return _medsubdomain.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medsubdomain.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medsubdomain.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medsubdomain.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medsubdomain.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medsubdomain.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medsubdomain.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medsubdomain.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medsubdomain.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medsubdomain.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medsubdomain.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medsubdomain.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medsubdomain.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medsubdomain.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medsubdomain.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medsubdomain.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medsubdomain.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medsubdomain.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medsubdomain.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medsubdomain.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medsubdomain.delete_MEDCHAR

# Register MEDCHAR in _medsubdomain:
_medsubdomain.MEDCHAR_swigregister(MEDCHAR)

MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDsubdomainJointCr(fid, localmeshname, jointname, description, domainnumber, remotemeshname):
    r"""
    MEDsubdomainJointCr(fid, localmeshname, jointname, description, domainnumber, remotemeshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    localmeshname: char const *const
    jointname: char const *const
    description: char const *const
    domainnumber: med_int const
    remotemeshname: char const *const

    """
    return _medsubdomain.MEDsubdomainJointCr(fid, localmeshname, jointname, description, domainnumber, remotemeshname)

def MEDsubdomainCorrespondenceWr(fid, meshname, jointname, numdt, numit, localentitytype, localgeotype, remoteentitytype, remotegeotype, nentity, correspondence):
    r"""
    MEDsubdomainCorrespondenceWr(fid, meshname, jointname, numdt, numit, localentitytype, localgeotype, remoteentitytype, remotegeotype, nentity, correspondence) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    jointname: char const *const
    numdt: med_int const
    numit: med_int const
    localentitytype: enum med_entity_type const
    localgeotype: med_geometry_type const
    remoteentitytype: enum med_entity_type const
    remotegeotype: med_geometry_type const
    nentity: med_int const
    correspondence: med_int const *const

    """
    return _medsubdomain.MEDsubdomainCorrespondenceWr(fid, meshname, jointname, numdt, numit, localentitytype, localgeotype, remoteentitytype, remotegeotype, nentity, correspondence)

def MEDnSubdomainJoint(fid, meshname):
    r"""
    MEDnSubdomainJoint(fid, meshname) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medsubdomain.MEDnSubdomainJoint(fid, meshname)

def MEDsubdomainJointInfo(fid, meshname, jointit):
    r"""
    MEDsubdomainJointInfo(fid, meshname, jointit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    jointit: int const

    """
    return _medsubdomain.MEDsubdomainJointInfo(fid, meshname, jointit)

def MEDsubdomainComputingStepInfo(fid, meshname, jointname, csit):
    r"""
    MEDsubdomainComputingStepInfo(fid, meshname, jointname, csit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    jointname: char const *const
    csit: int const

    """
    return _medsubdomain.MEDsubdomainComputingStepInfo(fid, meshname, jointname, csit)

def MEDsubdomainCorrespondenceSizeInfo(fid, meshname, jointname, numdt, numit, corit):
    r"""
    MEDsubdomainCorrespondenceSizeInfo(fid, meshname, jointname, numdt, numit, corit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    jointname: char const *const
    numdt: med_int const
    numit: med_int const
    corit: int const

    """
    return _medsubdomain.MEDsubdomainCorrespondenceSizeInfo(fid, meshname, jointname, numdt, numit, corit)

def MEDsubdomainCorrespondenceSize(fid, meshname, jointname, numdt, numit, localentitytype, localgeotype, remoteentitytype, remotegeotype):
    r"""
    MEDsubdomainCorrespondenceSize(fid, meshname, jointname, numdt, numit, localentitytype, localgeotype, remoteentitytype, remotegeotype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    jointname: char const *const
    numdt: med_int const
    numit: med_int const
    localentitytype: enum med_entity_type const
    localgeotype: med_geometry_type const
    remoteentitytype: enum med_entity_type const
    remotegeotype: med_geometry_type const

    """
    return _medsubdomain.MEDsubdomainCorrespondenceSize(fid, meshname, jointname, numdt, numit, localentitytype, localgeotype, remoteentitytype, remotegeotype)

def MEDsubdomainCorrespondenceRd(fid, meshname, jointname, numdt, numit, localentitytype, localgeotype, remoteentitytype, remotegeotype, correspondence):
    r"""
    MEDsubdomainCorrespondenceRd(fid, meshname, jointname, numdt, numit, localentitytype, localgeotype, remoteentitytype, remotegeotype, correspondence) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    jointname: char const *const
    numdt: med_int const
    numit: med_int const
    localentitytype: enum med_entity_type const
    localgeotype: med_geometry_type const
    remoteentitytype: enum med_entity_type const
    remotegeotype: med_geometry_type const
    correspondence: med_int *const

    """
    return _medsubdomain.MEDsubdomainCorrespondenceRd(fid, meshname, jointname, numdt, numit, localentitytype, localgeotype, remoteentitytype, remotegeotype, correspondence)

